==> igniteui-webcomponents-core-3.2.4.tgz: package/esm2015/lib/WebTabDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebTabDescription } from "./WebTabDescription";
/**
 * @hidden
 */
export let WebTabDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebTabDescriptionMetadata extends Base {
        static b(a) {
            if (WebTabDescriptionMetadata.a == null) {
                WebTabDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebTabDescriptionMetadata.c(WebTabDescriptionMetadata.a);
            }
            if (a.g(WebTabDescriptionMetadata.a)) {
                return;
            }
            a.s(WebTabDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:Tab");
            a.item("Panel", "String");
            a.item("Selected", "Boolean");
            a.item("Disabled", "Boolean");
        }
        static d(a) {
            WebTabDescriptionMetadata.b(a);
            a.u("WebTab", () => new WebTabDescription());
            a.t("WebTab", WebTabDescriptionMetadata.a);
        }
    }
    WebTabDescriptionMetadata.$t = /*@__PURE__*/ markType(WebTabDescriptionMetadata, 'WebTabDescriptionMetadata');
    WebTabDescriptionMetadata.a = null;
    return WebTabDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/WebTabDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebTabDescription } from "./WebTabDescription";
/**
 * @hidden
 */
export let WebTabDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebTabDescriptionMetadata extends Base {
        static b(a) {
            if (WebTabDescriptionMetadata.a == null) {
                WebTabDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebTabDescriptionMetadata.c(WebTabDescriptionMetadata.a);
            }
            if (a.j(WebTabDescriptionMetadata.a)) {
                return;
            }
            a.y(WebTabDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:Tab");
            a.item("__tagNameWC", "String:igc-tab");
            a.item("Panel", "String");
            a.item("Selected", "Boolean");
            a.item("Disabled", "Boolean");
        }
        static d(a) {
            WebTabDescriptionMetadata.b(a);
            a.aa("WebTab", () => new WebTabDescription());
            a.z("WebTab", WebTabDescriptionMetadata.a);
        }
    }
    WebTabDescriptionMetadata.$t = /*@__PURE__*/ markType(WebTabDescriptionMetadata, 'WebTabDescriptionMetadata');
    WebTabDescriptionMetadata.a = null;
    return WebTabDescriptionMetadata;
})();
